@@ -30,7 +30,7 @@ class AnalogFS {
   int open(const char* fn, int flags);
   int open(const char* fn, int flags, mode_t mode);
   int stat(const char* fn, struct ::stat* st);
-  int mkdir(const char* dir, mode_t mode);
+  int makeDir(const char* dir, mode_t mode);
   int64_t ftwsize(const char* dir);
   DIR* opendir(const char* dir);
 
