@@ -68,8 +68,14 @@ DataSettings::~DataSettings() {
  * @param parent 父窗口指针
  */
 void DataSettings::ResetDataEntry(Application* app, GtkWidget* parent) {
+  if (app->getPreferenceDialog()) {
+    gtk_window_present(GTK_WINDOW(app->getPreferenceDialog()));
+    return;
+  }
+
   DataSettings dset(app, parent);
   GtkWidget* dialog = GTK_WIDGET(dset.dialog());
+  app->setPreferenceDialog(dialog);
 
   /* 运行对话框 */
   gtk_widget_show_all(dialog);
@@ -98,6 +104,7 @@ void DataSettings::ResetDataEntry(Application* app, GtkWidget* parent) {
         break;
     }
   }
+  app->setPreferenceDialog(NULL);
 }
 
 /**
@@ -395,6 +402,14 @@ GtkWidget* DataSettings::CreateSystem() {
   gtk_grid_attach(GTK_GRID(box), widget, 0, row, 2, 1);
   g_datalist_set_data(&widset, "shared-check-widget", widget);
 
+#if HAVE_APPINDICATOR
+  row++;
+  widget = gtk_check_button_new_with_label(
+      _("Hide the taskbar when the main window is minimized"));
+  gtk_grid_attach(GTK_GRID(box), widget, 0, row, 2, 1);
+  g_datalist_set_data(&widset, "taskbar-check-widget", widget);
+#endif
+
   return GTK_WIDGET(box);
 }
 
@@ -553,7 +568,7 @@ void DataSettings::SetSystemValue() {
   gtk_font_chooser_set_font(GTK_FONT_CHOOSER(widget), g_progdt->font);
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "chat-check-widget"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
-                               g_progdt->IsAutoOpenCharDialog());
+                               g_progdt->IsAutoOpenChatDialog());
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "statusicon-check-widget"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
                                g_progdt->IsAutoHidePanelAfterLogin());
@@ -576,6 +591,12 @@ void DataSettings::SetSystemValue() {
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "shared-check-widget"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
                                g_progdt->IsFilterFileShareRequest());
+#if HAVE_APPINDICATOR
+  widget = GTK_WIDGET(g_datalist_get_data(&widset, "taskbar-check-widget"));
+  gtk_toggle_button_set_active(
+      GTK_TOGGLE_BUTTON(widget),
+      g_progdt->isHideTaskbarWhenMainWindowIconified());
+#endif
 }
 
 /**
@@ -836,7 +857,7 @@ string DataSettings::ObtainSystemValue(bool dryrun) {
   gint active;
 
   auto g_cthrd = app->getCoreThread();
-  auto g_progdt = g_cthrd->getProgramData();
+  auto progdt = g_cthrd->getProgramData();
 
   ostringstream oss;
 
@@ -858,9 +879,9 @@ string DataSettings::ObtainSystemValue(bool dryrun) {
     port_valid = false;
   }
 
-  if (port_valid && port != g_progdt->port()) {
+  if (port_valid && port != progdt->port()) {
     if (!dryrun) {
-      g_progdt->set_port(port);
+      progdt->set_port(port);
     }
   }
 
@@ -873,7 +894,7 @@ string DataSettings::ObtainSystemValue(bool dryrun) {
   text = gtk_editable_get_chars(GTK_EDITABLE(widget), 0, -1);
   g_strstrip(text);
   if (*text != '\0') {
-    g_progdt->codeset = text;
+    progdt->codeset = text;
   } else
     g_free(text);
 
@@ -881,7 +902,7 @@ string DataSettings::ObtainSystemValue(bool dryrun) {
   text = gtk_editable_get_chars(GTK_EDITABLE(widget), 0, -1);
   g_strstrip(text);
   if (*text != '\0') {
-    g_progdt->encode = text;
+    progdt->encode = text;
   } else
     g_free(text);
 
@@ -892,49 +913,58 @@ string DataSettings::ObtainSystemValue(bool dryrun) {
     snprintf(path, MAX_PATHLEN, "%d", active);
     gtk_tree_model_get_iter_from_string(model, &iter, path);
     gtk_tree_model_get(model, &iter, 1, &file, -1);
-    if (strcmp(g_progdt->palicon, file) != 0) {
+    if (strcmp(progdt->palicon, file) != 0) {
       snprintf(path, MAX_PATHLEN, __PIXMAPS_PATH "/icon/%s", file);
       if (access(path, F_OK) != 0) {
         g_free(file);
-        g_free(g_progdt->palicon);
-        g_progdt->palicon = g_strdup("pal-icon");
+        g_free(progdt->palicon);
+        progdt->palicon = g_strdup("pal-icon");
         snprintf(path, MAX_PATHLEN, "%s" ICON_PATH "/pal-icon",
                  g_get_user_config_dir());
         gtk_tree_model_get(model, &iter, 0, &pixbuf, -1);
         gdk_pixbuf_save(pixbuf, path, "png", NULL, NULL);
-        gtk_icon_theme_add_builtin_icon(g_progdt->palicon, MAX_ICONSIZE,
-                                        pixbuf);
+        gtk_icon_theme_add_builtin_icon(progdt->palicon, MAX_ICONSIZE, pixbuf);
         g_object_unref(pixbuf);
       } else {
-        g_free(g_progdt->palicon);
-        g_progdt->palicon = file;
+        g_free(progdt->palicon);
+        progdt->palicon = file;
       }
     } else
       g_free(file);
   }
 
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "font-chooser-widget"));
-  g_free(g_progdt->font);
-  g_progdt->font =
-      g_strdup(gtk_font_chooser_get_font(GTK_FONT_CHOOSER(widget)));
+  g_free(progdt->font);
+  progdt->font = g_strdup(gtk_font_chooser_get_font(GTK_FONT_CHOOSER(widget)));
 
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "chat-check-widget"));
-  g_progdt->SetFlag(7, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+  progdt->setOpenChat(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "statusicon-check-widget"));
-  g_progdt->SetFlag(6, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+  progdt->setHideStartup(
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
   widget =
       GTK_WIDGET(g_datalist_get_data(&widset, "transmission-check-widget"));
-  g_progdt->SetFlag(5, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+  progdt->setOpenTransmission(
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "enterkey-check-widget"));
-  g_progdt->SetFlag(4, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+  progdt->setUseEnterKey(
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "history-check-widget"));
-  g_progdt->SetFlag(3, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+  progdt->setClearupHistory(
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "log-check-widget"));
-  g_progdt->SetFlag(2, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+  progdt->setRecordLog(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "blacklist-check-widget"));
-  g_progdt->SetFlag(1, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+  progdt->setOpenBlacklist(
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
   widget = GTK_WIDGET(g_datalist_get_data(&widset, "shared-check-widget"));
-  g_progdt->SetFlag(0, gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+  progdt->setProofShared(
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+#if HAVE_APPINDICATOR
+  widget = GTK_WIDGET(g_datalist_get_data(&widset, "taskbar-check-widget"));
+  progdt->setHideTaskbarWhenMainWindowIconified(
+      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)));
+#endif
   return oss.str();
 }
 
