@@ -45,6 +45,8 @@ DialogBase::~DialogBase() {
   if (timersend > 0)
     g_source_remove(timersend);
   ClearSublayerGeneral();
+  if (grpinf)
+    grpinf->clearDialog();
 }
 
 /**
@@ -63,7 +65,6 @@ void DialogBase::ClearSublayerGeneral() {
   if (progdt->IsAutoCleanChatHistory()) {
     ClearHistoryTextView();
   }
-  grpinf->clearDialog();
   g_datalist_clear(&widset);
   g_datalist_clear(&mdlset);
   g_datalist_clear(&dtset);
@@ -252,13 +253,15 @@ GtkWidget* DialogBase::CreateInputArea() {
 
   widget = gtk_text_view_new_with_buffer(grpinf->getInputBuffer());
   inputTextviewWidget = GTK_TEXT_VIEW(widget);
-  gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(widget), GTK_WRAP_WORD);
+  gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(widget), GTK_WRAP_WORD_CHAR);
   gtk_drag_dest_add_uri_targets(widget);
   gtk_container_add(GTK_CONTAINER(sw), widget);
   g_signal_connect_swapped(widget, "drag-data-received",
                            G_CALLBACK(DragDataReceived), this);
   g_signal_connect_swapped(widget, "paste-clipboard",
                            G_CALLBACK(DialogBase::OnPasteClipboard), this);
+  g_signal_connect_swapped(widget, "populate-popup",
+                           G_CALLBACK(DialogBase::onInputPopulatePopup), this);
   g_datalist_set_data(&widset, "input-textview-widget", widget);
 
   /* 功能按钮 */
@@ -277,6 +280,23 @@ GtkWidget* DialogBase::CreateInputArea() {
   return frame;
 }
 
+static void iptux_dlg_refresh_anchors(DialogBase* dialog,
+                                      GtkTextBuffer* buffer) {
+  GtkTextIter start, end;
+  gtk_text_buffer_get_bounds(buffer, &start, &end);
+
+  GtkTextIter iter = start;
+  while (!gtk_text_iter_equal(&iter, &end)) {
+    GtkTextChildAnchor* anchor = gtk_text_iter_get_child_anchor(&iter);
+
+    if (anchor) {
+      dialog->onChatHistoryInsertChildAnchor(anchor);
+    }
+
+    gtk_text_iter_forward_char(&iter);
+  }
+}
+
 /**
  * 创建聊天历史记录区域.
  * @return 主窗体.
@@ -297,7 +317,7 @@ GtkWidget* DialogBase::CreateHistoryArea() {
       GTK_TEXT_VIEW(gtk_text_view_new_with_buffer(grpinf->buffer));
   gtk_text_view_set_cursor_visible(chat_history_widget, FALSE);
   gtk_text_view_set_editable(chat_history_widget, FALSE);
-  gtk_text_view_set_wrap_mode(chat_history_widget, GTK_WRAP_WORD);
+  gtk_text_view_set_wrap_mode(chat_history_widget, GTK_WRAP_WORD_CHAR);
   gtk_container_add(GTK_CONTAINER(sw), GTK_WIDGET(chat_history_widget));
   g_signal_connect(chat_history_widget, "key-press-event",
                    G_CALLBACK(textview_key_press_event), NULL);
@@ -305,13 +325,9 @@ GtkWidget* DialogBase::CreateHistoryArea() {
                    G_CALLBACK(textview_event_after), NULL);
   g_signal_connect(chat_history_widget, "motion-notify-event",
                    G_CALLBACK(textview_motion_notify_event), NULL);
-  g_signal_connect(chat_history_widget, "visibility-notify-event",
-                   G_CALLBACK(textview_visibility_notify_event), NULL);
-  g_signal_connect_data(grpinf->buffer, "insert-child-anchor",
-                        G_CALLBACK(DialogBase::OnChatHistoryInsertChildAnchor),
-                        this, NULL,
-                        (GConnectFlags)(G_CONNECT_AFTER | G_CONNECT_SWAPPED));
-
+  if (grpinf->buffer) {
+    iptux_dlg_refresh_anchors(this, grpinf->buffer);
+  }
   /* 滚动消息到最末位置 */
   ScrollHistoryTextview();
 
@@ -812,6 +828,15 @@ void DialogBase::OnPasteClipboard(DialogBase*, GtkTextView* textview) {
   }
 }
 
+void DialogBase::onInputPopulatePopup(DialogBase* self,
+                                      GtkWidget* popup,
+                                      GtkTextView* textview) {
+  if (!GTK_IS_MENU(popup))
+    return;
+
+  self->populateInputPopup(GTK_MENU(popup));
+}
+
 void DialogBase::afterWindowCreated() {
   g_return_if_fail(!m_imagePopupMenu);
 
@@ -849,10 +874,7 @@ gboolean DialogBase::OnImageButtonPress(DialogBase* self,
   return TRUE;
 }
 
-void DialogBase::OnChatHistoryInsertChildAnchor(DialogBase* self,
-                                                const GtkTextIter*,
-                                                GtkTextChildAnchor* anchor,
-                                                GtkTextBuffer*) {
+void DialogBase::onChatHistoryInsertChildAnchor(GtkTextChildAnchor* anchor) {
   const char* path =
       (const char*)g_object_get_data(G_OBJECT(anchor), kObjectKeyImagePath);
   if (!path) {
@@ -873,9 +895,9 @@ void DialogBase::OnChatHistoryInsertChildAnchor(DialogBase* self,
 
   gtk_container_add(GTK_CONTAINER(event_box), GTK_WIDGET(image));
   g_signal_connect_swapped(event_box, "button-press-event",
-                           G_CALLBACK(DialogBase::OnImageButtonPress), self);
+                           G_CALLBACK(DialogBase::OnImageButtonPress), this);
 
-  gtk_text_view_add_child_at_anchor(self->chat_history_widget, event_box,
+  gtk_text_view_add_child_at_anchor(this->chat_history_widget, event_box,
                                     anchor);
   gtk_widget_show_all(event_box);
 }
