@@ -11,28 +11,24 @@
 //
 #include "config.h"
 #include "MainWindow.h"
-
-#include <cinttypes>
+#include "iptux-core/Const.h"
+#include "iptux-utils/output.h"
+#include "iptux-utils/utils.h"
+#include "iptux/Application.h"
+#include "iptux/DetectPal.h"
+#include "iptux/DialogGroup.h"
+#include "iptux/DialogPeer.h"
+#include "iptux/RevisePal.h"
+#include "iptux/UiHelper.h"
+#include "iptux/UiModels.h"
+#include "iptux/callback.h"
+#include "iptux/dialog.h"
 #include <ctime>
 #include <glib/gi18n.h>
 #include <glog/logging.h>
 #include <string>
 #include <thread>
 
-#include "iptux-core/Const.h"
-#include "iptux-utils/output.h"
-#include "iptux-utils/utils.h"
-#include "iptux/DataSettings.h"
-#include "iptux/DetectPal.h"
-#include "iptux/DialogGroup.h"
-#include "iptux/DialogPeer.h"
-#include "iptux/RevisePal.h"
-#include "iptux/ShareFile.h"
-#include "iptux/UiHelper.h"
-#include "iptux/UiModels.h"
-#include "iptux/callback.h"
-#include "iptux/dialog.h"
-
 using namespace std;
 
 namespace iptux {
@@ -51,6 +47,23 @@ static const char* config_names[] = {
     [CFG_INFO_STYLE] = "mwin_info_style",
 };
 
+static void main_window_on_state_event(GtkWidget* self,
+                                       GdkEvent* event,
+                                       gpointer user_data) {
+  GdkWindowState event_state = event->window_state.new_window_state;
+  MainWindow* mwin = (MainWindow*)user_data;
+  auto progdt = mwin->getApp()->getProgramData();
+
+  if (!progdt->isHideTaskbarWhenMainWindowIconified())
+    return;
+
+  if (event_state & GDK_WINDOW_STATE_ICONIFIED) {
+    gtk_window_set_skip_taskbar_hint(GTK_WINDOW(self), TRUE);
+  } else {
+    gtk_window_set_skip_taskbar_hint(GTK_WINDOW(self), FALSE);
+  }
+}
+
 /**
  * 类构造函数.
  */
@@ -482,6 +495,8 @@ GtkWidget* MainWindow::CreateMainWindow() {
                    this);
   g_signal_connect(window, "delete-event",
                    G_CALLBACK(gtk_window_iconify_on_delete), nullptr);
+  g_signal_connect(window, "window-state-event",
+                   G_CALLBACK(main_window_on_state_event), this);
   return window;
 }
 
@@ -690,7 +705,6 @@ GtkWidget* MainWindow::CreatePaltreeTree(GtkTreeModel* model) {
   g_object_set_data(G_OBJECT(view), "info-column", column);
   /* 展开器区域 */
   cell = gtk_cell_renderer_pixbuf_new();
-  g_object_set(cell, "follow-state", TRUE, NULL);
   gtk_tree_view_column_pack_start(column, cell, FALSE);
   gtk_tree_view_column_set_attributes(
       GTK_TREE_VIEW_COLUMN(column), cell, "pixbuf",
@@ -753,7 +767,6 @@ GtkWidget* MainWindow::CreatePallistTree(GtkTreeModel* model) {
   gtk_tree_view_column_set_resizable(column, TRUE);
   gtk_tree_view_column_set_title(column, _("Nickname"));
   cell = gtk_cell_renderer_pixbuf_new();
-  g_object_set(cell, "follow-state", TRUE, NULL);
   gtk_tree_view_column_pack_start(column, cell, FALSE);
   gtk_tree_view_column_set_attributes(column, cell, "pixbuf", 0, NULL);
   cell = gtk_cell_renderer_text_new();
@@ -1671,7 +1684,7 @@ void MainWindow::ProcessEvent(shared_ptr<const Event> _event) {
     switch (para.btype) {
       case GROUP_BELONG_TYPE_REGULAR:
         grpinf = coreThread.GetPalRegularItem(para.getPal().get());
-        if (coreThread.getProgramData()->IsAutoOpenCharDialog()) {
+        if (coreThread.getProgramData()->IsAutoOpenChatDialog()) {
           if (!(grpinf->getDialog())) {
             DialogPeer::PeerDialogEntry(this->app, grpinf);
           } else {
