@@ -1,19 +1,16 @@
 #include "gtest/gtest.h"
 
-#include "iptux-core/TestHelper.h"
 #include "iptux/Application.h"
 #include "iptux/ShareFile.h"
+#include "iptux/TestHelper.h"
 
 using namespace std;
 using namespace iptux;
 
 TEST(ShareFile, Constructor) {
-  gtk_init(nullptr, nullptr);
-  auto config = newTestIptuxConfig();
-  Application app(config);
-  app.startup();
-  app.activate();
+  Application* app = CreateApplication();
 
-  ShareFile* shareFile = shareFileNew(&app);
+  ShareFile* shareFile = shareFileNew(app);
   gtk_widget_destroy(GTK_WIDGET(shareFile));
+  DestroyApplication(app);
 }
