@@ -377,7 +377,8 @@ const char* GtkSortTypeToStr(GtkSortType t) {
 //       buffer(NULL),
 //       dialog(NULL) {}
 GroupInfo::~GroupInfo() {
-  g_object_unref(buffer);
+  if (buffer)
+    g_object_unref(buffer);
 }
 
 bool GroupInfo::hasPal(PalInfo* pal) const {
@@ -465,6 +466,68 @@ void GroupInfo::newFileReceived() {
   this->signalNewFileReceived.emit(this);
 }
 
+bool GroupInfo::isInputEmpty() const {
+  GtkTextIter start, end;
+  gtk_text_buffer_get_bounds(inputBuffer, &start, &end);
+  return gtk_text_iter_equal(&start, &end);
+}
+
+shared_ptr<MsgPara> GroupInfo::genMsgParaFromInput() const {
+  static unsigned int count = 0;
+  GtkTextIter start;
+  GdkPixbuf* pixbuf;
+  char buf[7];
+  gchar* chipmsg;
+  std::vector<ChipData> dtlist;
+
+  gtk_text_buffer_get_start_iter(inputBuffer, &start);
+  ostringstream oss;
+  while (1) {
+    gunichar c = gtk_text_iter_get_char(&start);
+    if (!c)
+      break;
+    if (ig_unichar_is_atomic(c)) {
+      if (!oss.str().empty()) {
+        ChipData chip(MESSAGE_CONTENT_TYPE_STRING, oss.str());
+        dtlist.push_back(std::move(chip));
+        oss.str("");
+      }
+      pixbuf = gtk_text_iter_get_pixbuf(&start);
+      chipmsg =
+          g_strdup_printf("%s" SENT_IMAGE_PATH "/%d.png",
+                          g_get_user_cache_dir(), g_atomic_int_add(&count, 1));
+      GError* error = nullptr;
+      gdk_pixbuf_save(pixbuf, chipmsg, "png", &error, NULL);
+      if (error) {
+        LOG_ERROR("failed to save image: %s", error->message);
+        g_error_free(error);
+      } else {
+        /* 新建一个碎片数据(图片)，并加入数据链表 */
+        ChipData chip(MESSAGE_CONTENT_TYPE_PICTURE, chipmsg);
+        dtlist.push_back(std::move(chip));
+      }
+    } else {
+      int size = g_unichar_to_utf8(c, buf);
+      oss.write(buf, size);
+    }
+    gtk_text_iter_forward_char(&start);
+  }
+  if (!oss.str().empty()) {
+    ChipData chip(MESSAGE_CONTENT_TYPE_STRING, oss.str());
+    dtlist.push_back(std::move(chip));
+  }
+
+  auto para = make_shared<MsgPara>(this->getMembers()[0]);
+  para->stype = MessageSourceType::SELF;
+  para->btype = type;
+  para->dtlist = dtlist;
+  return para;
+}
+
+void GroupInfo::clearInputBuffer() {
+  gtk_text_buffer_set_text(inputBuffer, "", 0);
+}
+
 void GroupInfo::addMsgCount(int i) {
   int oldCount = getUnreadMsgCount();
   allMsgCount += i;
@@ -586,6 +649,24 @@ string GroupInfo::GetHintAsMarkup() const {
   return res.str();
 }
 
+void GroupInfo::initBuffer(GtkTextTagTable* tag_table) {
+  this->buffer = gtk_text_buffer_new(tag_table);
+  g_signal_connect_data(this->buffer, "insert-child-anchor",
+                        G_CALLBACK(GroupInfo::OnBufferInsertChildAnchor), this,
+                        NULL,
+                        (GConnectFlags)(G_CONNECT_AFTER | G_CONNECT_SWAPPED));
+}
+
+void GroupInfo::OnBufferInsertChildAnchor(GroupInfo* self,
+                                          const GtkTextIter*,
+                                          GtkTextChildAnchor* anchor,
+                                          GtkTextBuffer*) {
+  if (!self->dialogBase)
+    return;
+
+  self->dialogBase->onChatHistoryInsertChildAnchor(anchor);
+}
+
 /**
  * 插入字符串到TextBuffer(非UI线程安全).
  * @param buffer text-buffer
