@@ -91,6 +91,9 @@ class GroupInfo {
   void newFileReceived();
 
   GtkTextBuffer* getInputBuffer() const { return inputBuffer; }
+  bool isInputEmpty() const;
+  std::shared_ptr<MsgPara> genMsgParaFromInput() const;
+  void clearInputBuffer();
 
   void setDialogBase(DialogBase* dialogBase) { this->dialogBase = dialogBase; }
   GtkWidget* getDialog() const;
@@ -102,10 +105,18 @@ class GroupInfo {
   time_t last_activity() const { return last_activity_; }
   const std::string& last_message() const { return last_message_; }
 
+  void initBuffer(GtkTextTagTable* tag_table);
+
  public:
   sigc::signal<void(GroupInfo*, int, int)> signalUnreadMsgCountUpdated;
   sigc::signal<void(GroupInfo*)> signalNewFileReceived;
 
+ private:
+  static void OnBufferInsertChildAnchor(GroupInfo* self,
+                                        const GtkTextIter* location,
+                                        GtkTextChildAnchor* anchor,
+                                        GtkTextBuffer* buffer);
+
  public:
   GQuark grpid;           ///< 唯一标识
   GtkTextBuffer* buffer;  ///< 历史消息缓冲区 *
